aboutsummaryrefslogtreecommitdiffstats
path: root/OpenKeychain/src/main/java/org/sufficientlysecure/keychain/ui/SafeSlingerActivity.java
diff options
context:
space:
mode:
authorAdithya Abraham Philip <adithyaphilip@gmail.com>2015-06-01 17:43:00 +0530
committerAdithya Abraham Philip <adithyaphilip@gmail.com>2015-06-01 17:43:00 +0530
commit6bc40d12ad44c4170f10054fb8ea7d2c9459da35 (patch)
treea7b79e122d81bb3cd97b870ce38499e0778e9a0a /OpenKeychain/src/main/java/org/sufficientlysecure/keychain/ui/SafeSlingerActivity.java
parent14a08361e52bcd8bd26b9b2b2b9690276b40ed42 (diff)
downloadopen-keychain-6bc40d12ad44c4170f10054fb8ea7d2c9459da35.tar.gz
open-keychain-6bc40d12ad44c4170f10054fb8ea7d2c9459da35.tar.bz2
open-keychain-6bc40d12ad44c4170f10054fb8ea7d2c9459da35.zip
renamed KeychainIntentService to KeychainService
Diffstat (limited to 'OpenKeychain/src/main/java/org/sufficientlysecure/keychain/ui/SafeSlingerActivity.java')
-rw-r--r--OpenKeychain/src/main/java/org/sufficientlysecure/keychain/ui/SafeSlingerActivity.java12
1 files changed, 6 insertions, 6 deletions
diff --git a/OpenKeychain/src/main/java/org/sufficientlysecure/keychain/ui/SafeSlingerActivity.java b/OpenKeychain/src/main/java/org/sufficientlysecure/keychain/ui/SafeSlingerActivity.java
index bdebf2d75..273acc23d 100644
--- a/OpenKeychain/src/main/java/org/sufficientlysecure/keychain/ui/SafeSlingerActivity.java
+++ b/OpenKeychain/src/main/java/org/sufficientlysecure/keychain/ui/SafeSlingerActivity.java
@@ -38,7 +38,7 @@ import org.sufficientlysecure.keychain.operations.results.ImportKeyResult;
import org.sufficientlysecure.keychain.operations.results.OperationResult;
import org.sufficientlysecure.keychain.provider.KeychainContract;
import org.sufficientlysecure.keychain.provider.ProviderHelper;
-import org.sufficientlysecure.keychain.service.KeychainIntentService;
+import org.sufficientlysecure.keychain.service.KeychainService;
import org.sufficientlysecure.keychain.ui.base.BaseActivity;
import org.sufficientlysecure.keychain.service.ServiceProgressHandler;
import org.sufficientlysecure.keychain.ui.util.Notify;
@@ -123,7 +123,7 @@ public class SafeSlingerActivity extends BaseActivity {
final FragmentActivity activity = SafeSlingerActivity.this;
// Message is received after importing is done in KeychainIntentService
ServiceProgressHandler saveHandler = new ServiceProgressHandler(
activity,
getString(R.string.progress_importing),
@@ -176,9 +176,9 @@ public class SafeSlingerActivity extends BaseActivity {
Log.d(Constants.TAG, "importKeys started");
// Send all information needed to service to import key in other thread
- Intent intent = new Intent(activity, KeychainIntentService.class);
+ Intent intent = new Intent(activity, KeychainService.class);
- intent.setAction(KeychainIntentService.ACTION_IMPORT_KEYRING);
+ intent.setAction(KeychainService.ACTION_IMPORT_KEYRING);
// instead of giving the entries by Intent extra, cache them into a
// file to prevent Java Binder problems on heavy imports
@@ -195,11 +195,11 @@ public class SafeSlingerActivity extends BaseActivity {
// fill values for this action
Bundle bundle = new Bundle();
- intent.putExtra(KeychainIntentService.EXTRA_DATA, bundle);
+ intent.putExtra(KeychainService.EXTRA_DATA, bundle);
// Create a new Messenger for the communication back
Messenger messenger = new Messenger(saveHandler);
- intent.putExtra(KeychainIntentService.EXTRA_MESSENGER, messenger);
+ intent.putExtra(KeychainService.EXTRA_MESSENGER, messenger);
// show progress dialog
saveHandler.showProgressDialog(activity);
@@ -123,7 +123,7 @@ public class SafeSlingerActivity extends BaseActivity {
final FragmentActivity activity = SafeSlingerActivity.this;
- // Message is received after importing is done in KeychainIntentService
+ // Message is received after importing is done in KeychainService
ServiceProgressHandler saveHandler = new ServiceProgressHandler(
activity,